<?php

class Op5reports_Test extends TapUnit {
	/**
	 * to "add sub options" means we're combining options' properties
	 */
	function test_default_values() {
		$op5reports = new Op5reports_options();
		$sla = new Sla_options(false);
		$this->ok($op5reports['report_period'] != $sla['report_period'], "Default value for report periods differs (prerequisite)");

		$op5reports = new Op5reports_options($sla);
		$this->ok_eq($sla['report_period'], $op5reports['report_period'], "The default value of a sub report is prioritized");
	}

	function test_default_values_are_overridden_in_the_order_sub_reports_are_added() {
		$sla = new Sla_options(false);
		$summary = new Summary_options();
		$op5reports = new Op5reports_options();
		$this->ok($summary['report_period'] != $sla['report_period'], "Indicate that the following tests are not useless, that we have a valid entrypoint");
		$op5reports->add_sub('sla', array());
		$this->ok_eq($sla['report_period'], $op5reports['report_period'], "The default value of a sub report is checked in the reverse order of when it was added");
		$op5reports->add_sub('summary', array());
		$this->ok_eq($summary['report_period'], $op5reports['report_period'], "The default value of a sub report is checked in the reverse order of when it was added");
	}

	function test_unkown_option_is_false() {
		$op5reports = new Op5reports_options();
		$this->ok_eq(false, $op5reports['red_fish$blue fish'], "todo");
	}

	/**
	 * bug #6364
	 */
	function test_load_report() {
		$expected = array(
			'report_name' => 'TEST_REPORT',
			'use_summary' => 1,
			'host_filter_status' => array(-2, -2),
			'scheduleddowntimeasuptime' => 1,
			'use_pnp' => 1,
			'host_name' => array('monitor')
		);
		Op5reports_Options::$type = 'avail';
		$report = Report_Options::setup_options_obj('op5reports');
		$report->add_sub('avail', false);

		foreach ($expected as $k => $v) {
			$this->ok($report->set($k, $v), "Setting $k to ".var_export($v, true)." should work");
		}
		$id = Saved_reports_Model::edit_report_info('avail', false, $report);
		$this->ok($id !== false, 'Saving report should work');

		Op5reports_Options::$type = 'avail';
		$loaded_report = Report_Options::setup_options_obj('op5reports', array('report_id' => $id));
		$loaded_report->add_sub('avail', array('report_id' => $id));

		foreach ($expected as $k => $v) {
			$this->ok_eq($loaded_report[$k], $v, "Loaded report should have $k set to ".var_export($v, true));
		}

		$this->ok(Saved_reports_Model::delete_report('avail', $id), "Deleting report once we're done is successful");
	}
}
